@@ -8,33 +8,34 @@ from __future__ import absolute_import, unicode_literals, division
 import logging
 import collections
 
+try:
+    from lxml.etree import iterparse
+
+    def xml_clear_elem(elem):
+        elem.clear()
+        while elem.getprevious() is not None:
+            del elem.getparent()[0]
+
+except ImportError:
+    try:
+        from xml.etree.cElementTree import iterparse
+    except ImportError:
+        from xml.etree.ElementTree import iterparse
+
+    def xml_clear_elem(elem):
+        elem.clear()
+
+
 logger = logging.getLogger(__name__)
 
 ParsedDictionary = collections.namedtuple('ParsedDictionary', 'lexemes links grammemes version revision')
 
+
 def parse_opencorpora_xml(filename):
     """
     Parse OpenCorpora dict XML and return a ``ParsedDictionary`` namedtuple.
     """
 
-    try:
-        from lxml.etree import iterparse
-
-        def _clear(elem):
-            elem.clear()
-            while elem.getprevious() is not None:
-                del elem.getparent()[0]
-
-    except ImportError:
-        try:
-            from xml.etree.cElementTree import iterparse
-        except ImportError:
-            from xml.etree.ElementTree import iterparse
-
-        def _clear(elem):
-            elem.clear()
-
-
     links = []
     lexemes = {}
     grammemes = []
@@ -48,7 +49,7 @@ def parse_opencorpora_xml(filename):
                 version = elem.get('version')
                 revision = elem.get('revision')
                 logger.info("dictionary v%s, rev%s", version, revision)
-                _clear(elem)
+                xml_clear_elem(elem)
             continue
 
         if elem.tag == 'grammeme':
@@ -57,10 +58,9 @@ def parse_opencorpora_xml(filename):
             alias = elem.find('alias').text
             description = elem.find('description').text
 
-            grameme = (name, parent, alias, description)
-            grammemes.append(grameme)
-            _clear(elem)
-
+            grammeme = (name, parent, alias, description)
+            grammemes.append(grammeme)
+            xml_clear_elem(elem)
 
         if elem.tag == 'lemma':
             if not lexemes:
@@ -68,7 +68,7 @@ def parse_opencorpora_xml(filename):
 
             lex_id, word_forms = _word_forms_from_xml_elem(elem)
             lexemes[lex_id] = word_forms
-            _clear(elem)
+            xml_clear_elem(elem)
 
         elif elem.tag == 'link':
             if not links:
@@ -80,7 +80,7 @@ def parse_opencorpora_xml(filename):
                 elem.get('type'),
             )
             links.append(link_tuple)
-            _clear(elem)
+            xml_clear_elem(elem)
 
         if len(lexemes) != _lexemes_len and not (len(lexemes) % 50000):
             logger.debug("%d lexemes parsed" % len(lexemes))
@@ -89,14 +89,14 @@ def parse_opencorpora_xml(filename):
     return ParsedDictionary(lexemes, links, grammemes, version, revision)
 
 
-def _tags_from_elem(elem):
+def _grammemes_from_elem(elem):
     return ",".join(g.get('v') for g in elem.findall('g'))
 
+
 def _word_forms_from_xml_elem(elem):
     """
-    Return a list of (word, tags) pairs given "lemma" XML element.
+    Return a list of (word, tag) pairs given "lemma" XML element.
     """
-
     lexeme = []
     lex_id = elem.get('id')
 
@@ -106,13 +106,13 @@ def _word_forms_from_xml_elem(elem):
     base_info = elem.findall('l')
 
     assert len(base_info) == 1
-    base_tags = _tags_from_elem(base_info[0])
+    base_grammemes = _grammemes_from_elem(base_info[0])
 
     for form_elem in elem.findall('f'):
-        tags = _tags_from_elem(form_elem)
+        grammemes = _grammemes_from_elem(form_elem)
         form = form_elem.get('t').lower()
         lexeme.append(
-            (form, " ".join([base_tags, tags]).strip())
+            (form, " ".join([base_grammemes, grammemes]).strip())
         )
 
     return lex_id, lexeme
